// Include custom about page
.course-info.about {
    &.container {
        padding-top: 50px;
        padding-bottom: 20px;
        @include media-breakpoint-up(md) {
            padding-top: 70px;
            padding-bottom: 70px;
        }
    }
    header.course-profile {
        overflow: visible;
        background: none;
        .intro-inner-wrapper {
            background: none;
            padding: 0 0 60px;
            @include media-breakpoint-up(md) {
                padding: 0 0 20px;
            }
            @include media-breakpoint-up(lg) {
                padding: 36px 0 60px;
            }
        }
    }
    .intro-inner-wrapper .profile-top {
        &:after {
            display: block;
            content: "";
            clear: both;
        }
        .info-profile {
            overflow: hidden;
            padding: 0 0 10px;
            @include media-breakpoint-up(md) {
                padding: 0 0 70px;
            }
            h1 {
                font-size: 24px;
                font-weight: 800;
                margin: 0 0 8px;
                line-height: 30px;
                color: #111827;
                text-align: left;
            }
            .org {
                display: block;
                color: #515661;
                font-size: 16px;
                line-height: 22px;
            }
        }
        .media {
            margin: 0 auto 20px;
            padding: 0;
            display: block;
            max-width: 400px;
            width: 100%;
            @include media-breakpoint-up(md) {
                float: right;
                width: 32%;
                margin: 0 0 0 80px;
            }
            img {
                display: block;
                width: 100%;
                height: auto;
                position: relative;
                z-index: 1;
                border-radius: 8px;
                height: 180px;
                object-fit: cover;
            }
            .hero {
                position: relative;
                overflow: visible;
                border: none;
                &:after {
                    position: absolute;
                    left: 1px;
                    top: 1px;
                    width: calc(100% - 2px);
                    height: calc(100% - 2px);
                    content: "";
                    border-radius: 8px;
                    border: 1px solid $primary-light;
                }
                .play-intro{
                    z-index: 10;
                }
            }
        }
    }
    .main-cta {
        @include media-breakpoint-up(md) {
            margin: -50px 0 0;
        }
        span {
          &.register {
            &.disabled {
              display: inline-block;
              vertical-align: top;
              padding: 7px 14px;
              color: #374151;
              border-radius: 6px;
              background: #fff;
              font-size: 16px;
              line-height: 24px;
              font-weight: 500;
              text-decoration: none !important;
              border: 1px solid #D1D5DB;
              margin-right: 20px;
              @include media-breakpoint-up(md) {
                  padding: 12px 24px;
              }

              &:hover {
                opacity: 1;
              }
            }
          }
        }

        a {
            display: inline-block;
            text-decoration: none !important;
        }
        a.register, a strong, >span.register, a.add-to-cart {
            display: inline-block;
            vertical-align: top;
            padding: 8px 15px;
            color: #fff;
            border-radius: 6px;
            background: $primary;
            font-size: 16px;
            line-height: 24px;
            font-weight: 500;
            text-decoration: none !important;
            @include media-breakpoint-up(md) {
                padding: 13px 25px;
            }
            &:hover {
                text-decoration: none;
                opacity: .8;
            }
        }
        span.closed {
            background: $primary-light;
            border-radius: 6px;
            color: #9CA3AF;
            font-size: 16px;
            line-height: 24px;
            padding: 16px;
            font-weight: 500;
            display: inline-block;
            vertical-align: top;
        }
    }
    .about-content {
        display: flex;
        flex-flow: column-reverse;
        flex-wrap: wrap;
        @include media-breakpoint-up(md) {
            display: block;
        }
        &:after {
            display: block;
            clear: both;
            content: "";
        }
        .details {
            width: 100%;
            @include media-breakpoint-up(md) {
                width: calc(100% - 32% - 35px);
                margin-right: 35px;
            }
            @include media-breakpoint-up(lg) {
                width: calc(100% - 32% - 57px);
                margin-right: 57px;
            }
            .wrap-instructor-info {
                display: none;
            }
            .about, .prerequisites, .course-staff, .faq {
                font: 16px/20px $font-family-title;
                color: #515661;
                border-radius: 8px;
                border: 1px solid $primary-light;
                border-left: 14px solid $primary-light;
                padding: 24px 16px 10px 16px;
                margin: 0 0 20px;
                .responses {
                    float: none;
                    width: 100%;
                }
                p {
                    margin: 0 0 14px;
                }
                h2 {
                    margin: 0 0 14px;
                    color: #111827;
                    font-size: 18px;
                    line-height: 24px;
                    font-weight: 600;
                }
                h3 {
                    margin: 0 0 5px;
                    color: #4B5563;
                    font-size: 14px;
                    line-height: 20px;
                    font-weight: 500;
                }
                .response {
                    margin: 0 0 12px;
                    &:last-child {
                        margin: 0;
                    }
                }
                .teacher {
                    margin: 0 0 38px;
                    &:last-child {
                        margin: 0 0 14px;
                    }
                    &.update {
                        position: relative;
                        overflow: hidden;
                        @include media-breakpoint-up(md) {
                            &:after {
                                position: absolute;
                                width: 1px;
                                height: 100%;
                                content: "";
                                top: 0;
                                left: 145px;
                                background: $primary-light;
                            }
                        }
                        .teacher-info {
                            overflow: hidden;
                        }
                        .teacher-image {
                            text-align: left;
                            border: none;
                            height: auto;
                            margin: 0 0 5px;
                            float: none;
                            width: auto;
                            @include media-breakpoint-up(md) {
                                margin: 0 30px 0 0;
                                width: 130px;
                                float: left;
                                text-align: center;
                            }
                            img {
                                width: 60px;
                                border-radius: 50%;
                                display: block;
                                margin: 0 0 12px;
                                float: none;
                                @include media-breakpoint-up(md) {
                                    margin: 0 auto 12px;
                                }
                            }
                            h3 {
                                margin: 0;
                            }
                        }
                    }
                }
            }
        }
    }
    .course-sidebar {
        background: $primary-light;
        padding: 24px;
        border-radius: 8px;
        width: 100%;
        box-sizing: border-box;
        margin: 0 0 25px;
        @include media-breakpoint-up(md) {
            width: 32%;
            margin: 0;
            max-width: 400px;
            float: right;
        }
        h2 {
            color:#111827;
            font-size: 20px;
            line-height: 28px;
            font-weight: 700;
            margin: 0 0 20px;
        }
        header {
            padding: 0;
            margin: 0;
            border: none;
            text-align: left;
            &:after {
                display: none;
            }
            .social-sharing {
                height: auto;
                text-align: left;
                .sharing-message {
                    background: white;
                    border: none;
                    border-top: 4px solid $primary;
                    color: #000;
                    font: 10px/15px $font-family-title;
                    padding: 10px;
                }
                .share {
                    width: auto;
                    height: auto;
                    opacity: 1;
                    margin-right: 10px;
                    vertical-align: top;
                }
            }
        }
        .important-dates {
            padding: 0;
            li {
                position: relative;
                padding: 0 0 20px 36px;
                overflow: hidden;
                border: none;
                margin: 0;
                svg, .fa {
                    position: absolute;
                    line-height: 24px;
                    font-size: 17px;
                    left: 0;
                    top: 0;
                    margin: 0;
                    color: #9CA3AF;
                    opacity: 1;
                }
                p {
                    font-size: 14px;
                    font-weight: 500;
                    line-height: 24px;
                    float: none;
                    color: #4B5563;
                    margin: 0 0 5px;
                    font-family: $font-family-title;
                    float: left;
                    @include media-breakpoint-up(md) {
                        float: none;
                    }
                    @include media-breakpoint-up(lg) {
                        float: left;
                    }
                }
                .important-dates-item-text {
                    float: none;
                    font-size: 12px;
                    line-height: 24px;
                    color: #515661;
                    display: block;
                    font-weight: normal;
                    font-family: $font-family-title;
                    float: right;
                    @include media-breakpoint-up(md) {
                        float: none;
                    }
                    @include media-breakpoint-up(lg) {
                        float: right;
                    }
                }
            }
        }
    }
}
body.indigo-dark-theme {
    .course-info.about {
        .intro-inner-wrapper .profile-top {
            .info-profile {
                h1 {
                    color: $text-color-d;
                }
                .org {
                    color: $text-color-primary;
                }
            }
            .media {
                .hero {
                    &:after {
                        border-color: $border-color-d;
                    }
                }
            }
        }
        .main-cta {
            a {
                span {
                    color: $text-color-d;
                    background: none;
                    border: 1px solid $text-color-d;
                }
            }
            a.register, a strong, >span.register, a.add-to-cart {
                color: $btn-color-d;
                background: $primary-d;
            }
            span.closed {
                background: $primary-light-d;
            }
        }
        .about-content {
            .details {
                .about, .prerequisites, .course-staff, .faq {
                    color: $text-color-d;
                    border: 1px solid $primary-light-d;
                    border-left: 14px solid $primary-light-d;
                    h2 {
                        color: $text-color-d;
                    }
                    h3 {
                        color: $text-color-d;
                    }
                    .teacher {
                        &.update {
                            @include media-breakpoint-up(md) {
                                &:after {
                                    background: $primary-light-d;
                                }
                            }
                        }
                    }
                }
            }
        }
        .course-sidebar {
            background: $primary-light-d;
            h2 {
                color: $text-color-d;
            }
            header {
                .social-sharing {
                    .sharing-message {
                        background: $primary-light-d;
                        border-top: 4px solid $primary-d;
                        color: $text-color-d;
                    }
                }
            }
            .important-dates {
                li {
                    svg, .fa {
                        color: $text-color-primary;
                        path {
                            fill: $text-color-primary;
                        }
                    }
                    p {
                        color: $text-color-primary;
                    }
                    .important-dates-item-text {
                        color: $text-color-primary;
                    }
                }
            }
        }
    }
}