## mako

<%page expression_filter="h"/>

<%namespace name='static' file='../static_content.html'/>
<%namespace file='../main.html' import="login_query"/>

<%!
from django.conf import settings
from django.urls import reverse
from django.utils.translation import gettext as _
%>

<%
  mktg_site_enabled = static.get_value('ENABLE_MKTG_SITE', settings.FEATURES.get('ENABLE_MKTG_SITE', False))
  courses_are_browsable = settings.FEATURES.get('COURSES_ARE_BROWSABLE')
  allows_login = not settings.FEATURES['DISABLE_LOGIN_BUTTON'] and not combined_login_and_register
  can_discover_courses = settings.FEATURES.get('ENABLE_COURSE_DISCOVERY')
  allow_public_account_creation = static.get_value('ALLOW_PUBLIC_ACCOUNT_CREATION', settings.FEATURES.get('ALLOW_PUBLIC_ACCOUNT_CREATION')) and settings.FEATURES.get('SHOW_REGISTRATION_LINKS', True)
%>
<!-- NEW IN INDIGO update nav -->
<nav class="nav-links" aria-label=${_("Supplemental Links")}>
  <div class="main">
  % if mktg_site_enabled:
    <div class="mobile-nav-item hidden-mobile nav-item">
      <a href="${marketing_link('HOW_IT_WORKS')}">${_("How it Works")}</a>
    </div>
    % if courses_are_browsable:
      <div class="mobile-nav-item hidden-mobile nav-item">
        <a href="${marketing_link('COURSES')}">${_("Courses")}</a>
      </div>
    % endif
    <div class="mobile-nav-item hidden-mobile nav-item">
      <a href="${marketing_link('SCHOOLS')}">${_("Schools")}</a>
    </div>
  % endif
  % if allows_login:
    % if can_discover_courses:
      <div class="mobile-nav-item hidden-mobile nav-item nav-tab">
        <a href="/courses">${_('Discover courses')}</a>
      </div>
    %endif
  % endif
  </div>
  <div class="secondary d-flex align-items-center">
    <%include file="./theme-toggle-button.html" />
    <div class="btn-holder">
      % if allows_login:
        % if allow_public_account_creation and not disable_register_button:
            <div class="mobile-nav-item hidden-mobile nav-item">
                <a class="register-btn btn" href="/register${login_query()}">${_("Register for free")}</a>
            </div>
        % endif
        <div class="mobile-nav-item hidden-mobile nav-item">
            <a class="sign-in-btn btn" href="/login${login_query()}">${_("Sign in")}</a>
        </div>
      % endif
    </div>
  </div>
</nav>
